@@ -15,10 +15,12 @@
 #' @export
 get_tau <- function(items,
                     key = NULL,
-                    itembank = dscore::builtin_itembank) {
-  # set default key
-  if (is.null(key) || key == "gsed") {
-    key <- "gsed2212"
+                    itembank = dscore::builtin_itembank,
+                    verbose = FALSE) {
+  key <- set_default_key(key)
+
+  if (verbose) {
+    cat("key:        ", key, "\n")
   }
 
   # if key = "", then search in all rows
